package com.ruoyi.ggpx.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.ggpx.service.ITaskDataService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ggpx.domain.TaskBase;
import com.ruoyi.ggpx.service.ITaskBaseService;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 任务基准Controller
 *
 * @author Jian
 * @date 2024-08-11
 */
@RestController
@RequestMapping("/ggpx/TaskBase")
public class TaskBaseController extends BaseController {
    @Autowired
    private ITaskBaseService taskBaseService;

    /**
     * 查询任务基准列表
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskBase:list')")
    @GetMapping("/list")
    public AjaxResult list(TaskBase taskBase) {
        List<TaskBase> list = taskBaseService.selectTaskBaseList(taskBase);
        return success(list);
    }

    /**
     * 查询任务基准列表
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskBase:list')")
    @GetMapping("/listPage")
    public TableDataInfo listPage(TaskBase taskBase) {
        startPage();
        List<TaskBase> list = taskBaseService.selectTaskBaseList(taskBase);
        return getDataTable(list);
    }

    /**
     * 导出任务基准列表
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskBase:export')")
    @Log(title = "任务基准", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TaskBase taskBase) {
        List<TaskBase> list = taskBaseService.selectTaskBaseList(taskBase);
        ExcelUtil<TaskBase> util = new ExcelUtil<TaskBase>(TaskBase.class);
        util.exportExcel(response, list, "任务基准数据");
    }

    /**
     * 获取任务基准详细信息
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskBase:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(taskBaseService.selectTaskBaseById(id));
    }

    /**
     * 新增任务基准
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskBase:add')")
    @Log(title = "任务基准", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TaskBase taskBase) {
        return toAjax(taskBaseService.insertTaskBase(taskBase));
    }

    @PreAuthorize("@ss.hasPermi('ggpx:TaskBase:add')")
    @Log(title = "任务基准", businessType = BusinessType.INSERT)
    @PostMapping("/batch")
    public AjaxResult addBatch(@RequestBody List<TaskBase> taskBaseList) {
        return toAjax(taskBaseService.insertTaskBaseBatch(taskBaseList));
    }

    /**
     * 修改任务基准
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskBase:edit')")
    @Log(title = "任务基准", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TaskBase taskBase) {
        return toAjax(taskBaseService.updateTaskBase(taskBase));
    }

    /**
     * 删除任务基准
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskBase:remove')")
    @Log(title = "任务基准", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(taskBaseService.deleteTaskBaseByIds(ids));
    }
}
