package com.ruoyi.ggpx.controller;

import java.io.IOException;
import java.util.*;
import javax.annotation.security.PermitAll;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.domain.entity.SysRole;
import com.ruoyi.common.utils.poi.ExcelExporter;
import com.ruoyi.ggpx.domain.TaskDataQuery;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ggpx.domain.TaskData;
import com.ruoyi.ggpx.service.ITaskDataService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 任务数据Controller
 *
 * @author Jian
 * @date 2024-08-11
 */
@RestController
@RequestMapping("/ggpx/TaskData")
public class TaskDataController extends BaseController {
    @Autowired
    private ITaskDataService taskDataService;

    /**
     * 查询任务数据列表
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskData:list')")
    @GetMapping("/list")
    public TableDataInfo list(TaskData taskData) {
        startPage();
        List<TaskData> list = taskDataService.selectTaskDataList(taskData);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('ggpx:TaskData:list')")
    @GetMapping("/count")
    public AjaxResult count(TaskData taskData) {
        return success(taskDataService.selectTaskDataCount(taskData));
    }

    /**
     * 导出所有填写的数据
     *
     * @param taskData
     * @param response
     * @throws IOException
     */
    @PostMapping("/toEXCEL")
    public void taskDataToCSV(TaskDataQuery taskData, HttpServletResponse response) throws IOException {
        List<TaskData> list = new ArrayList<>();
        Long[] ids = taskData.getIds();
        if (ids == null || ids.length == 0) {
            list = taskDataService.selectTaskDataList(taskData);
        } else {
            list = taskDataService.selectTaskDataListByIds(taskData, ids);
        }
        List<Map<String, Object>> csvList = new ArrayList<>();
        list.forEach(item -> {
            Map<String, Object> csvMap = new LinkedHashMap<>();
            csvMap.put("样品名称", item.getSampleName());
            csvMap.put("组长", item.getGroupLeader());
            csvMap.put("总分", item.getTotalVal());
            List fields = JSONObject.parseObject(item.getData(), List.class);
            fields.forEach(field -> {
                Map fieldMap = JSONObject.parseObject(field.toString(), Map.class);
                Object children = fieldMap.get("children");
                if (children != null) {
                    List childrenList = JSONObject.parseObject(children.toString(), List.class);
                    childrenList.forEach(childrenField -> {
                        Map childrenFieldMap = JSONObject.parseObject(childrenField.toString(), Map.class);
                        if (childrenFieldMap.get("fieldType").toString().equals("number")) {
                            csvMap.put(childrenFieldMap.get("fieldName").toString(), childrenFieldMap.getOrDefault("value", 0));
                        } else {
                            csvMap.put(childrenFieldMap.get("fieldName").toString(), childrenFieldMap.getOrDefault("value", ""));
                        }
                    });
                } else {
                    if (fieldMap.get("fieldType").toString().equals("number")) {
                        csvMap.put(fieldMap.get("fieldName").toString(), fieldMap.getOrDefault("value", 0));
                    } else {
                        csvMap.put(fieldMap.get("fieldName").toString(), fieldMap.getOrDefault("value", ""));
                    }
                }
            });
            csvList.add(csvMap);
        });
        if (csvList.size() == 0) {
            return;
        }
        Set<String> columns = csvList.get(0).keySet();
        // columns转数组
        String[] columnsArray = columns.toArray(new String[columns.size()]);
        ExcelExporter.exportExcel(csvList, columnsArray, "任务数据", response);
    }

    /**
     * 导出二级指标&&计入总分的数据--用于进一步统计
     *
     * @param taskData
     * @param response
     * @throws IOException
     */
    @PostMapping("/toEXCEL2")
    public void taskDataToCSV2(TaskDataQuery taskData, HttpServletResponse response) throws IOException {
        List<TaskData> list = new ArrayList<>();
        Long[] ids = taskData.getIds();
        if (ids == null || ids.length == 0) {
            list = taskDataService.selectTaskDataList(taskData);
        } else {
            list = taskDataService.selectTaskDataListByIds(taskData, ids);
        }
        List<Map<String, Object>> csvList = new ArrayList<>();
        list.forEach(item -> {
            Map<String, Object> csvMap = new LinkedHashMap<>();
            csvMap.put("样品名称", item.getSampleName());
            List fields = JSONObject.parseObject(item.getData(), List.class);
            fields.forEach(field -> {
                Map fieldMap = JSONObject.parseObject(field.toString(), Map.class);
                Object children = fieldMap.get("children");
                if (children != null) {
                    List childrenList = JSONObject.parseObject(children.toString(), List.class);
                    childrenList.forEach(childrenField -> {
                        Map childrenFieldMap = JSONObject.parseObject(childrenField.toString(), Map.class);
                        if ((int) childrenFieldMap.getOrDefault("status", 1) == 0) {
                            csvMap.put(childrenFieldMap.get("fieldName").toString(), childrenFieldMap.getOrDefault("value", 0));
                        }
                    });
                }
            });
            csvList.add(csvMap);
        });
        if (csvList.size() == 0) {
            return;
        }
        Set<String> columns = csvList.get(0).keySet();
        // columns转数组
        String[] columnsArray = columns.toArray(new String[columns.size()]);
        ExcelExporter.exportExcel(csvList, columnsArray, "任务数据", response);
    }

    @GetMapping("/radar")
    public AjaxResult radarData(TaskDataQuery taskData) {
        List<TaskData> list = new ArrayList<>();
        Long[] ids = taskData.getIds();
        if (ids == null || ids.length == 0) {
            list = taskDataService.selectTaskDataList(taskData);
        } else {
            list = taskDataService.selectTaskDataListByIds(taskData, ids);
        }
        return success(list);
    }


    /**
     * 导出任务数据列表
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskData:export')")
    @Log(title = "任务数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TaskData taskData) {
        List<TaskData> list = taskDataService.selectTaskDataList(taskData);
        ExcelUtil<TaskData> util = new ExcelUtil<TaskData>(TaskData.class);
        util.exportExcel(response, list, "任务数据数据");
    }

    /**
     * 获取任务数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskData:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(taskDataService.selectTaskDataById(id));
    }

    /**
     * 新增任务数据
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskData:add')")
    @Log(title = "任务数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TaskData taskData) {
        List<SysRole> roles = this.getLoginUser().getUser().getRoles();
        roles.forEach(role -> {
            if (role.getRoleKey().equals("pxry-leader")) {
                taskData.setGroupLeader("是");
            }
        });
        return toAjax(taskDataService.insertTaskData(taskData));
    }

    /**
     * 修改任务数据
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskData:edit')")
    @Log(title = "任务数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TaskData taskData) {
        List<SysRole> roles = this.getLoginUser().getUser().getRoles();
        roles.forEach(role -> {
            if (role.getRoleKey().equals("pxry-leader")) {
                taskData.setGroupLeader("是");
            }
        });
        return toAjax(taskDataService.updateTaskData(taskData));
    }

    /**
     * 删除任务数据
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskData:remove')")
    @Log(title = "任务数据", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(taskDataService.deleteTaskDataByIds(ids));
    }
}
