package com.ruoyi.ggpx.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.ggpx.domain.TaskData;
import com.ruoyi.ggpx.service.ITaskBaseService;
import com.ruoyi.ggpx.service.ITaskDataService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ggpx.domain.TaskList;
import com.ruoyi.ggpx.service.ITaskListService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 任务列表Controller
 *
 * @author Jian
 * @date 2024-08-11
 */
@RestController
@RequestMapping("/ggpx/TaskList")
public class TaskListController extends BaseController {
    @Autowired
    private ITaskListService taskListService;

    @Autowired
    private ITaskDataService taskDataService;

    /**
     * 查询任务列表列表
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskList:list')")
    @GetMapping("/list")
    public TableDataInfo list(TaskList taskList) {
        startPage();
        List<TaskList> list = taskListService.selectTaskListList(taskList);
        list.forEach(item -> {
            TaskData taskData = new TaskData();
            taskData.setTaskId(item.getId());
            item.setSampleCount((taskDataService.selectTaskDataCount(taskData)));
        });
        return getDataTable(list);
    }

    /**
     * 导出任务列表列表
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskList:export')")
    @Log(title = "任务列表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TaskList taskList) {
        List<TaskList> list = taskListService.selectTaskListList(taskList);
        ExcelUtil<TaskList> util = new ExcelUtil<TaskList>(TaskList.class);
        util.exportExcel(response, list, "任务列表数据");
    }

    /**
     * 获取任务列表详细信息
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskList:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(taskListService.selectTaskListById(id));
    }

    @PreAuthorize("@ss.hasPermi('ggpx:TaskList:query')")
    @GetMapping(value = "/statistics/{id}")
    public AjaxResult getStatistics(@PathVariable("id") Long id) {
        TaskList taskList = taskListService.selectTaskListById(id);
        if (taskList.getIsTemplate() == 1) {
            return AjaxResult.success("操作成功", taskList.getStatistics());
        } else {
            TaskList taskListQuery = new TaskList();
            taskListQuery.setId(taskList.getParentId());
            taskListQuery.setIsTemplate(1);
            List<TaskList> taskLists = taskListService.selectTaskListList(taskListQuery);
            if (taskLists.size() > 0) {
                return AjaxResult.success("操作成功", taskLists.get(0).getStatistics());
            }
        }
        return AjaxResult.success("操作成功", "");
    }

    @PreAuthorize("@ss.hasPermi('ggpx:TaskList:add')")
    @Log(title = "任务列表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult addBatch(@RequestBody TaskList taskList) {
        taskListService.insertTaskList(taskList);
        return success(taskList.getId());
    }

    /**
     * 修改任务列表
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskList:edit')")
    @Log(title = "任务列表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TaskList taskList) {
        return toAjax(taskListService.updateTaskList(taskList));
    }

    /**
     * 删除任务列表
     */
    @PreAuthorize("@ss.hasPermi('ggpx:TaskList:remove')")
    @Log(title = "任务列表", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(taskListService.deleteTaskListByIds(ids));
    }
}
