package com.ruoyi.ggpx.service.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.stream.Collectors;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ggpx.mapper.TaskBaseMapper;
import com.ruoyi.ggpx.domain.TaskBase;
import com.ruoyi.ggpx.service.ITaskBaseService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 任务基准Service业务层处理
 *
 * @author Jian
 * @date 2024-08-11
 */
@Service
public class TaskBaseServiceImpl implements ITaskBaseService {
    @Autowired
    private TaskBaseMapper taskBaseMapper;

    /**
     * 查询任务基准
     *
     * @param id 任务基准主键
     * @return 任务基准
     */
    @Override
    public TaskBase selectTaskBaseById(Long id) {
        return taskBaseMapper.selectTaskBaseById(id);
    }

    /**
     * 查询任务基准列表
     *
     * @param taskBase 任务基准
     * @return 任务基准
     */
    @Override
    public List<TaskBase> selectTaskBaseList(TaskBase taskBase) {
        return taskBaseMapper.selectTaskBaseList(taskBase);
    }

    /**
     * 新增任务基准
     *
     * @param taskBase 任务基准
     * @return 结果
     */
    @Override
    public int insertTaskBase(TaskBase taskBase) {
        taskBase.setCreateTime(DateUtils.getNowDate());
        return taskBaseMapper.insertTaskBase(taskBase);
    }

    @Override
    @Transactional
    public int insertTaskBaseBatch(List<TaskBase> taskBaseList) {
        AtomicInteger count = new AtomicInteger();
        List<TaskBase> parentList = taskBaseList.stream().filter(taskBase -> taskBase.getParentId() == 0).collect(Collectors.toList());
        HashMap<Long, List<TaskBase>> childMap = new HashMap<>();
        for (TaskBase taskBase : taskBaseList) {
            if (taskBase.getParentId() == 0) {
                List<TaskBase> collect = taskBaseList.stream().filter(f -> f.getParentId().equals(taskBase.getId())).collect(Collectors.toList());
                childMap.put(taskBase.getId(), collect);
            }
        }

        for (TaskBase taskBase : parentList) {
            List<TaskBase> childList = childMap.get(taskBase.getId());
            taskBase.setId(null);
            taskBase.setCreateTime(DateUtils.getNowDate());
            count.addAndGet(taskBaseMapper.insertTaskBase(taskBase));
            long newParentId = taskBase.getId();
            if (childList != null) {
                childList.forEach(child -> {
                    child.setParentId(taskBase.getId());
                    child.setId(null);
                    child.setParentId(newParentId);
                    child.setCreateTime(DateUtils.getNowDate());
                    count.addAndGet(taskBaseMapper.insertTaskBase(child));
                });
            }
        }
        return count.get();
    }

    @Override
    @Transactional
    public int insertTaskBaseBatch(List<TaskBase> taskBaseList, Long newTaskId) {
        AtomicInteger count = new AtomicInteger();
        List<TaskBase> parentList = taskBaseList.stream().filter(taskBase -> taskBase.getParentId() == 0).collect(Collectors.toList());
        HashMap<Long, List<TaskBase>> childMap = new HashMap<>();
        for (TaskBase taskBase : taskBaseList) {
            if (taskBase.getParentId() == 0) {
                List<TaskBase> collect = taskBaseList.stream().filter(f -> f.getParentId().equals(taskBase.getId())).collect(Collectors.toList());
                childMap.put(taskBase.getId(), collect);
            }
        }

        for (TaskBase taskBase : parentList) {
            List<TaskBase> childList = childMap.get(taskBase.getId());
            taskBase.setId(null);
            taskBase.setCreateTime(DateUtils.getNowDate());
            taskBase.setTaskId(newTaskId);
            count.addAndGet(taskBaseMapper.insertTaskBase(taskBase));
            long newParentId = taskBase.getId();
            if (childList != null) {
                childList.forEach(child -> {
                    child.setId(null);
                    child.setTaskId(newTaskId);
                    child.setParentId(newParentId);
                    child.setCreateTime(DateUtils.getNowDate());
                    count.addAndGet(taskBaseMapper.insertTaskBase(child));
                });
            }
        }
        return count.get();
    }

    /**
     * 修改任务基准
     *
     * @param taskBase 任务基准
     * @return 结果
     */
    @Override
    public int updateTaskBase(TaskBase taskBase) {
        taskBase.setUpdateTime(DateUtils.getNowDate());
        return taskBaseMapper.updateTaskBase(taskBase);
    }

    /**
     * 批量删除任务基准
     *
     * @param ids 需要删除的任务基准主键
     * @return 结果
     */
    @Override
    public int deleteTaskBaseByIds(Long[] ids) {
        return taskBaseMapper.deleteTaskBaseByIds(ids);
    }

    /**
     * 删除任务基准信息
     *
     * @param id 任务基准主键
     * @return 结果
     */
    @Override
    public int deleteTaskBaseById(Long id) {
        return taskBaseMapper.deleteTaskBaseById(id);
    }
}
