package com.ruoyi.ggpx.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ggpx.mapper.TaskDataMapper;
import com.ruoyi.ggpx.domain.TaskData;
import com.ruoyi.ggpx.service.ITaskDataService;

/**
 * 任务数据Service业务层处理
 * 
 * @author Jian
 * @date 2024-08-11
 */
@Service
public class TaskDataServiceImpl implements ITaskDataService 
{
    @Autowired
    private TaskDataMapper taskDataMapper;

    /**
     * 查询任务数据
     * 
     * @param id 任务数据主键
     * @return 任务数据
     */
    @Override
    public TaskData selectTaskDataById(Long id)
    {
        return taskDataMapper.selectTaskDataById(id);
    }

    /**
     * 查询任务数据列表
     * 
     * @param taskData 任务数据
     * @return 任务数据
     */
    @Override
    public List<TaskData> selectTaskDataList(TaskData taskData)
    {
        return taskDataMapper.selectTaskDataList(taskData);
    }

    @Override
    public List<TaskData> selectTaskDataListByIds(TaskData taskData,Long[] ids)
    {
        return taskDataMapper.selectTaskDataListByIds(taskData,ids);
    }

    public int selectTaskDataCount(TaskData taskData){return taskDataMapper.selectTaskDataCount(taskData);}



    /**
     * 新增任务数据
     * 
     * @param taskData 任务数据
     * @return 结果
     */
    @Override
    public int insertTaskData(TaskData taskData)
    {
        taskData.setCreateTime(DateUtils.getNowDate());
        return taskDataMapper.insertTaskData(taskData);
    }

    /**
     * 修改任务数据
     * 
     * @param taskData 任务数据
     * @return 结果
     */
    @Override
    public int updateTaskData(TaskData taskData)
    {
        taskData.setUpdateTime(DateUtils.getNowDate());
        return taskDataMapper.updateTaskData(taskData);
    }

    /**
     * 批量删除任务数据
     * 
     * @param ids 需要删除的任务数据主键
     * @return 结果
     */
    @Override
    public int deleteTaskDataByIds(Long[] ids)
    {
        return taskDataMapper.deleteTaskDataByIds(ids);
    }

    /**
     * 删除任务数据信息
     * 
     * @param id 任务数据主键
     * @return 结果
     */
    @Override
    public int deleteTaskDataById(Long id)
    {
        return taskDataMapper.deleteTaskDataById(id);
    }
}
