package com.ruoyi.ggpx.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.ggpx.domain.TaskBase;
import com.ruoyi.ggpx.service.ITaskBaseService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ggpx.mapper.TaskListMapper;
import com.ruoyi.ggpx.domain.TaskList;
import com.ruoyi.ggpx.service.ITaskListService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 任务列表Service业务层处理
 *
 * @author Jian
 * @date 2024-08-11
 */
@Service
public class TaskListServiceImpl implements ITaskListService {
    @Autowired
    private TaskListMapper taskListMapper;


    @Autowired
    private ITaskBaseService taskBaseService;

    /**
     * 查询任务列表
     *
     * @param id 任务列表主键
     * @return 任务列表
     */
    @Override
    public TaskList selectTaskListById(Long id) {
        return taskListMapper.selectTaskListById(id);
    }

    /**
     * 查询任务列表列表
     *
     * @param taskList 任务列表
     * @return 任务列表
     */
    @Override
    public List<TaskList> selectTaskListList(TaskList taskList) {
        return taskListMapper.selectTaskListList(taskList);
    }

    /**
     * 新增任务列表
     *
     * @param taskList 任务列表
     * @return 结果
     */
    @Override
    @Transactional
    public int insertTaskList(TaskList taskList) {
        taskList.setCreateTime(DateUtils.getNowDate());
        taskListMapper.insertTaskList(taskList);

        TaskBase taskBase = new TaskBase();
        taskBase.setTaskId(taskList.getParentId());
        List<TaskBase> taskBaseList = taskBaseService.selectTaskBaseList(taskBase);

        taskBaseService.insertTaskBaseBatch(taskBaseList, taskList.getId());

        return taskList.getId().intValue();
    }

    /**
     * 修改任务列表
     *
     * @param taskList 任务列表
     * @return 结果
     */
    @Override
    public int updateTaskList(TaskList taskList) {
        taskList.setUpdateTime(DateUtils.getNowDate());
        return taskListMapper.updateTaskList(taskList);
    }

    /**
     * 批量删除任务列表
     *
     * @param ids 需要删除的任务列表主键
     * @return 结果
     */
    @Override
    public int deleteTaskListByIds(Long[] ids) {
        return taskListMapper.deleteTaskListByIds(ids);
    }

    /**
     * 删除任务列表信息
     *
     * @param id 任务列表主键
     * @return 结果
     */
    @Override
    public int deleteTaskListById(Long id) {
        return taskListMapper.deleteTaskListById(id);
    }
}
